CasError

Struct CasError 

pub struct CasError<T, E> { /* private fields */ }
Terminal CAS error returned by crate::CasExecutor.

Implementations

Source

impl<T, E> CasError<T, E>

pub fn kind(&self) -> CasErrorKind

Returns the classified CAS error kind.

Returns

High-level CAS error kind derived from the retry-layer reason and last attempt failure.

pub fn reason(&self) -> RetryErrorReason

Returns the retry-layer terminal reason.

Returns

Underlying RetryErrorReason.

pub fn context(&self) -> CasContext

Returns the terminal CAS context.

Returns

Copied CAS context captured when execution stopped.

pub fn attempts(&self) -> u32

Returns the number of attempts that were executed.

Returns

One-based attempt count.

pub fn last_failure(&self) -> Option<&CasAttemptFailure<T, E>>

Returns the last CAS attempt failure when one exists.

Returns

Some(&CasAttemptFailure<T, E>) when at least one attempt failed.

pub fn current(&self) -> Option<&Arc<T>>

Returns the current state associated with the last failure.

Returns

Some(&Arc<T>) when the terminal error preserved a current state.

pub fn error(&self) -> Option<&E>

Returns the business error associated with the last failure.

Returns

Some(&E) for retryable or aborting business failures.