pub struct ContentionThresholds { /* private fields */ }Expand description
Thresholds used to classify one execution as hotly contended.
Implementations
Sourceimpl ContentionThresholds
impl ContentionThresholds
Sourcepub fn new(min_attempts: u32, min_conflicts: u32, conflict_ratio: f64) -> Self
pub fn new(min_attempts: u32, min_conflicts: u32, conflict_ratio: f64) -> Self
Creates contention thresholds from raw values.
The conflict ratio is clamped to [0.0, 1.0].
Parameters
min_attempts: Minimum attempts before ratio check is meaningful.min_conflicts: Minimum absolute conflicts required.conflict_ratio: Minimum conflict ratio (clamped to [0.0, 1.0]).
Returns
A normalized ContentionThresholds value.
Sourcepub fn min_attempts(&self) -> u32
pub fn min_attempts(&self) -> u32
Returns the minimum attempt count.
Returns
Minimum number of attempts before a ratio is considered meaningful.
Sourcepub fn min_conflicts(&self) -> u32
pub fn min_conflicts(&self) -> u32
Returns the minimum conflict count.
Returns
Minimum raw number of conflicts required to be considered hot.
Sourcepub fn conflict_ratio(&self) -> f64
pub fn conflict_ratio(&self) -> f64